# RebuildIndexFilter lite
#
# Release 0.01 (Sep 10, 2008)
# Release 0.02 (Sep 12, 2008) change script-name check.
# Release 0.03 (Apr 30, 2013) change logic.
#
# This software is provided as-is. You may use it for commercial or
# personal use. If you distribute it, please keep this notice intact.
#
# Copyright (c) 2004-2013 Yujiro Araki

package MT::Plugin::RebuildIndexFilter;

use strict;
use warnings;
use MT;
use base qw( MT::Plugin );

our $VERSION = '0.03';

my $plugin = __PACKAGE__->new ({
    id   => 'rebuildindexfilter',
    name => 'RebuildIndexFilter Lite',
    description => '<MT_TRANS phrase="Filter index when rebuild.">',
    doc_link => 'http://www.koikikukan.com/archives/2008/09/10-005555.php',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    l10n_class => 'RebuildIndexFilter::L10N',
    version => $VERSION,
});
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
             'build_file_filter' => \&rebuild_index_filter,
        },
   });
}

sub rebuild_index_filter {
    my ($eh, %args) = @_;
    return 1 if $args{'ArchiveType'} ne 'index';

    my $app = MT->instance;
    my $q = $app->param;
    my $script = $ENV{'SCRIPT_NAME'};
    my $text = $args{'Template'}->text;

    my $admin_script = $app->config('AdminScript');
    my @event = ('entry','page','comment','ping');
    if ($script =~ /$admin_script/) {
        my $return_args = $q->param('return_args');
        (my $type = $return_args) =~ s/.*_type=([a-z]+)&.*/$1/;
        for my $event (@event) {
            return 1 if ($type eq $event || $type eq 'template') && ($text =~ /<mt\:?ignore>$event<\/mt\:?ignore>/);
        }
    }

    my $comment_script = $app->config('CommentScript');
    if ($script =~ /$comment_script/) {
        return 1 if $text =~ /<mt\:?ignore>comment<\/mt\:?ignore>/;
    }

    my $trackback_script = $app->config('TrackbackScript');
    if ($script =~ /$trackback_script/) {
        return 1 if $text =~ /<mt\:?ignore>ping<\/mt\:?ignore>/;
    }

    for my $event (@event) {
        return 0 if $text =~ /<mt\:?ignore>$event<\/mt\:?ignore>/;
    }
    return 1;
}

1;
